@@ -50,6 +50,7 @@ static const char *tests[] = {
                               "affine_reg",
                               "alphaops_reg",
                               "alphaxform_reg",
+                              "baseline_reg",
                               "bilateral2_reg",
                               "bilinear_reg",
                               "binarize_reg",
@@ -58,6 +59,7 @@ static const char *tests[] = {
                               "blend2_reg",
                               "blend3_reg",
                               "blend4_reg",
+                              "boxa1_reg",
                               "ccthin1_reg",
                               "ccthin2_reg",
                               "cmapquant_reg",
@@ -72,6 +74,7 @@ static const char *tests[] = {
                               "compare_reg",
                               "compfilter_reg",
                               "conncomp_reg",
+                              "conversion_reg",
                               "convolve_reg",
                               "dewarp_reg",
                               "distance_reg",
@@ -106,6 +109,7 @@ static const char *tests[] = {
                               "lineremoval_reg",
                               "logicops_reg",
                               "maze_reg",
+                              "mtiff_reg",
                               "multitype_reg",
                               "nearline_reg",
                               "newspaper_reg",
@@ -116,6 +120,7 @@ static const char *tests[] = {
                               "pdfseg_reg",
                               "pixa2_reg",
                               "pixadisp_reg",
+                              "pixcomp_reg",
                               "pixserial_reg",
                               "pngio_reg",
                               "pnmio_reg",
