@@ -27,12 +27,10 @@
 /*
  * conversion_reg.c
  *
- *    Regression test (_reg) for depth conversion functions,
+ *    Regression test for depth conversion functions,
  *    including some of the octcube quantization.
  */
 
-#define  DFLAG    1
-
 #include "allheaders.h"
 
 int main(int    argc,
@@ -42,13 +40,13 @@ char        *errorstr;
 l_int32      same, error;
 PIX         *pixs1, *pixs2, *pixs4, *pixs8, *pixs16, *pixs32;
 PIX         *pixc2, *pixc4, *pixc8;
-PIX         *pixt1, *pixt2, *pixt3, *pixt4, *pixt5, *pixt6;
+PIX         *pix1, *pix2, *pix3, *pix4, *pix5, *pix6;
 PIXCMAP     *cmap;
 SARRAY      *sa;
-static char  mainName[] = "convert_reg";
+L_REGPARAMS  *rp;
 
-    if (argc != 1)
-        return ERROR_INT(" Syntax:  convert_reg", mainName, 1);
+    if (regTestSetup(argc, argv, &rp))
+        return 1;
 
     pixs1 = pixRead("test1.png");
     pixs2 = pixRead("dreyfus2.png");
@@ -63,247 +61,263 @@ static char  mainName[] = "convert_reg";
     sa = sarrayCreate(0);
 
         /* Conversion: 1 bpp --> 8 bpp --> 1 bpp */
-    pixt1 = pixConvertTo8(pixs1, FALSE);
-    pixt2 = pixThreshold8(pixt1, 1, 0, 0);
-    pixEqual(pixs1, pixt2, &same);
+    pix1 = pixConvertTo8(pixs1, FALSE);
+    pix2 = pixThreshold8(pix1, 1, 0, 0);
+    regTestComparePix(rp, pixs1, pix2);  /* 0 */
+    pixEqual(pixs1, pix2, &same);
     if (!same) {
-        pixDisplayWithTitle(pixs1, 100, 100, "1 bpp, no cmap", DFLAG);
-        pixDisplayWithTitle(pixt2, 500, 100, "1 bpp, no cmap", DFLAG);
+        pixDisplayWithTitle(pixs1, 100, 100, "1 bpp, no cmap", 1);
+        pixDisplayWithTitle(pix2, 500, 100, "1 bpp, no cmap", 1);
         error = TRUE;
         sarrayAddString(sa, (char *)"conversion 1 bpp <==> 8 bpp", L_COPY);
     } else
         fprintf(stderr, "OK: conversion 1 bpp <==> 8 bpp\n");
-    pixDestroy(&pixt1);
-    pixDestroy(&pixt2);
+    pixDestroy(&pix1);
+    pixDestroy(&pix2);
 
         /* Conversion: 2 bpp --> 8 bpp --> 2 bpp */
         /* Conversion: 2 bpp cmap --> 8 bpp cmap --> 2 bpp cmap */
-    pixt1 = pixRemoveColormap(pixs2, REMOVE_CMAP_TO_GRAYSCALE);
-    pixt2 = pixThreshold8(pixt1, 2, 4, 0);
-    pixt3 = pixConvertTo8(pixt2, FALSE);
-    pixt4 = pixThreshold8(pixt3, 2, 4, 0);
-    pixEqual(pixt2, pixt4, &same);
+    pix1 = pixRemoveColormap(pixs2, REMOVE_CMAP_TO_GRAYSCALE);
+    pix2 = pixThreshold8(pix1, 2, 4, 0);
+    pix3 = pixConvertTo8(pix2, FALSE);
+    pix4 = pixThreshold8(pix3, 2, 4, 0);
+    regTestComparePix(rp, pix2, pix4);  /* 1 */
+    pixEqual(pix2, pix4, &same);
     if (!same) {
-        pixDisplayWithTitle(pixt2, 100, 100, "2 bpp, no cmap", DFLAG);
-        pixDisplayWithTitle(pixt4, 500, 100, "2 bpp, no cmap", DFLAG);
+        pixDisplayWithTitle(pix2, 100, 100, "2 bpp, no cmap", 1);
+        pixDisplayWithTitle(pix4, 500, 100, "2 bpp, no cmap", 1);
         error = TRUE;
         sarrayAddString(sa, (char *)"conversion 2 bpp <==> 8 bpp", L_COPY);
     } else
         fprintf(stderr, "OK: conversion 2 bpp <==> 8 bpp\n");
-    pixt5 = pixConvertTo8(pixs2, TRUE);
-    pixt6 = pixThreshold8(pixt5, 2, 4, 1);
-    pixEqual(pixs2, pixt6, &same);
+    pix5 = pixConvertTo8(pixs2, TRUE);
+    pix6 = pixThreshold8(pix5, 2, 4, 1);
+    regTestComparePix(rp, pixs2, pix6);  /* 2 */
+    pixEqual(pixs2, pix6, &same);
     if (!same) {
-        pixDisplayWithTitle(pixs2, 100, 100, "2 bpp, cmap", DFLAG);
-        pixDisplayWithTitle(pixt6, 500, 100, "2 bpp, cmap", DFLAG);
+        pixDisplayWithTitle(pixs2, 100, 100, "2 bpp, cmap", 1);
+        pixDisplayWithTitle(pix6, 500, 100, "2 bpp, cmap", 1);
         error = TRUE;
         sarrayAddString(sa, (char *)"conversion 2 bpp <==> 8 bpp; cmap",
                         L_COPY);
     } else
         fprintf(stderr, "OK: conversion 2 bpp <==> 8 bpp; cmap\n");
-    pixDestroy(&pixt1);
-    pixDestroy(&pixt2);
-    pixDestroy(&pixt3);
-    pixDestroy(&pixt4);
-    pixDestroy(&pixt5);
-    pixDestroy(&pixt6);
+    pixDestroy(&pix1);
+    pixDestroy(&pix2);
+    pixDestroy(&pix3);
+    pixDestroy(&pix4);
+    pixDestroy(&pix5);
+    pixDestroy(&pix6);
 
         /* Conversion: 4 bpp --> 8 bpp --> 4 bpp */
         /* Conversion: 4 bpp cmap --> 8 bpp cmap --> 4 bpp cmap */
-    pixt1 = pixRemoveColormap(pixs4, REMOVE_CMAP_TO_GRAYSCALE);
-    pixt2 = pixThreshold8(pixt1, 4, 16, 0);
-    pixt3 = pixConvertTo8(pixt2, FALSE);
-    pixt4 = pixThreshold8(pixt3, 4, 16, 0);
-    pixEqual(pixt2, pixt4, &same);
+    pix1 = pixRemoveColormap(pixs4, REMOVE_CMAP_TO_GRAYSCALE);
+    pix2 = pixThreshold8(pix1, 4, 16, 0);
+    pix3 = pixConvertTo8(pix2, FALSE);
+    pix4 = pixThreshold8(pix3, 4, 16, 0);
+    regTestComparePix(rp, pix2, pix4);  /* 3 */
+    pixEqual(pix2, pix4, &same);
     if (!same) {
-        pixDisplayWithTitle(pixt2, 100, 100, "4 bpp, no cmap", DFLAG);
-        pixDisplayWithTitle(pixt4, 500, 100, "4 bpp, no cmap", DFLAG);
+        pixDisplayWithTitle(pix2, 100, 100, "4 bpp, no cmap", 1);
+        pixDisplayWithTitle(pix4, 500, 100, "4 bpp, no cmap", 1);
         error = TRUE;
         sarrayAddString(sa, (char *)"conversion 4 bpp <==> 8 bpp", L_COPY);
     } else
         fprintf(stderr, "OK: conversion 4 bpp <==> 8 bpp\n");
-    pixt5 = pixConvertTo8(pixs4, TRUE);
-    pixt6 = pixThreshold8(pixt5, 4, 16, 1);
-    pixEqual(pixs4, pixt6, &same);
+    pix5 = pixConvertTo8(pixs4, TRUE);
+    pix6 = pixThreshold8(pix5, 4, 16, 1);
+    regTestComparePix(rp, pixs4, pix6);  /* 4 */
+    pixEqual(pixs4, pix6, &same);
     if (!same) {
-        pixDisplayWithTitle(pixs4, 100, 100, "4 bpp, cmap", DFLAG);
-        pixDisplayWithTitle(pixt6, 500, 100, "4 bpp, cmap", DFLAG);
+        pixDisplayWithTitle(pixs4, 100, 100, "4 bpp, cmap", 1);
+        pixDisplayWithTitle(pix6, 500, 100, "4 bpp, cmap", 1);
         error = TRUE;
         sarrayAddString(sa, (char *)"conversion 4 bpp <==> 8 bpp, cmap",
                         L_COPY);
     } else
         fprintf(stderr, "OK: conversion 4 bpp <==> 8 bpp; cmap\n");
-    pixDestroy(&pixt1);
-    pixDestroy(&pixt2);
-    pixDestroy(&pixt3);
-    pixDestroy(&pixt4);
-    pixDestroy(&pixt5);
-    pixDestroy(&pixt6);
+    pixDestroy(&pix1);
+    pixDestroy(&pix2);
+    pixDestroy(&pix3);
+    pixDestroy(&pix4);
+    pixDestroy(&pix5);
+    pixDestroy(&pix6);
 
         /* Conversion: 2 bpp cmap --> 2 bpp --> 2 bpp cmap --> 2 bpp */
-    pixt1 = pixRemoveColormap(pixs2, REMOVE_CMAP_TO_GRAYSCALE);
-    pixt2 = pixConvertGrayToColormap(pixt1);
-    pixt3 = pixRemoveColormap(pixt2, REMOVE_CMAP_TO_GRAYSCALE);
-    pixt4 = pixThresholdTo2bpp(pixt3, 4, 1);
-    pixEqual(pixt1, pixt4, &same);
+    pix1 = pixRemoveColormap(pixs2, REMOVE_CMAP_TO_GRAYSCALE);
+    pix2 = pixConvertGrayToColormap(pix1);
+    pix3 = pixRemoveColormap(pix2, REMOVE_CMAP_TO_GRAYSCALE);
+    pix4 = pixThresholdTo2bpp(pix3, 4, 1);
+    regTestComparePix(rp, pix1, pix4);  /* 5 */
+    pixEqual(pix1, pix4, &same);
     if (!same) {
-        pixDisplayWithTitle(pixs2, 100, 100, "2 bpp, cmap", DFLAG);
-        pixDisplayWithTitle(pixt4, 500, 100, "2 bpp, cmap", DFLAG);
+        pixDisplayWithTitle(pixs2, 100, 100, "2 bpp, cmap", 1);
+        pixDisplayWithTitle(pix4, 500, 100, "2 bpp, cmap", 1);
         error = TRUE;
         sarrayAddString(sa, (char *)"conversion 2 bpp <==> 2 bpp", L_COPY);
     } else
         fprintf(stderr, "OK: conversion 2 bpp <==> 2 bpp\n");
-    pixDestroy(&pixt1);
-    pixDestroy(&pixt2);
-    pixDestroy(&pixt3);
-    pixDestroy(&pixt4);
+    pixDestroy(&pix1);
+    pixDestroy(&pix2);
+    pixDestroy(&pix3);
+    pixDestroy(&pix4);
 
         /* Conversion: 4 bpp cmap --> 4 bpp --> 4 bpp cmap --> 4 bpp */
-    pixt1 = pixRemoveColormap(pixs4, REMOVE_CMAP_TO_GRAYSCALE);
-    pixt2 = pixConvertGrayToColormap(pixt1);
-    pixt3 = pixRemoveColormap(pixt2, REMOVE_CMAP_TO_GRAYSCALE);
-    pixt4 = pixThresholdTo4bpp(pixt3, 16, 1);
-    pixEqual(pixt1, pixt4, &same);
+    pix1 = pixRemoveColormap(pixs4, REMOVE_CMAP_TO_GRAYSCALE);
+    pix2 = pixConvertGrayToColormap(pix1);
+    pix3 = pixRemoveColormap(pix2, REMOVE_CMAP_TO_GRAYSCALE);
+    pix4 = pixThresholdTo4bpp(pix3, 16, 1);
+    regTestComparePix(rp, pix1, pix4);  /* 6 */
+    pixEqual(pix1, pix4, &same);
     if (!same) {
-        pixDisplayWithTitle(pixs4, 100, 100, "4 bpp, cmap", DFLAG);
-        pixDisplayWithTitle(pixt4, 500, 100, "4 bpp, cmap", DFLAG);
+        pixDisplayWithTitle(pixs4, 100, 100, "4 bpp, cmap", 1);
+        pixDisplayWithTitle(pix4, 500, 100, "4 bpp, cmap", 1);
         error = TRUE;
         sarrayAddString(sa, (char *)"conversion 4 bpp <==> 4 bpp", L_COPY);
     } else
         fprintf(stderr, "OK: conversion 4 bpp <==> 4 bpp\n");
-    pixDestroy(&pixt1);
-    pixDestroy(&pixt2);
-    pixDestroy(&pixt3);
-    pixDestroy(&pixt4);
+    pixDestroy(&pix1);
+    pixDestroy(&pix2);
+    pixDestroy(&pix3);
+    pixDestroy(&pix4);
 
 
         /* Conversion: 8 bpp --> 8 bpp cmap --> 8 bpp */
-    pixt1 = pixConvertTo8(pixs8, TRUE);
-    pixt2 = pixConvertTo8(pixt1, FALSE);
-    pixEqual(pixs8, pixt2, &same);
+    pix1 = pixConvertTo8(pixs8, TRUE);
+    pix2 = pixConvertTo8(pix1, FALSE);
+    regTestComparePix(rp, pixs8, pix2);  /* 7 */
+    pixEqual(pixs8, pix2, &same);
     if (!same) {
-        pixDisplayWithTitle(pixt1, 100, 100, "8 bpp, cmap", DFLAG);
-        pixDisplayWithTitle(pixt2, 500, 100, "8 bpp, no cmap", DFLAG);
+        pixDisplayWithTitle(pix1, 100, 100, "8 bpp, cmap", 1);
+        pixDisplayWithTitle(pix2, 500, 100, "8 bpp, no cmap", 1);
         error = TRUE;
         sarrayAddString(sa, (char *)"conversion 8 bpp <==> 8 bpp", L_COPY);
     } else
         fprintf(stderr, "OK: conversion 8 bpp <==> 8 bpp\n");
-    pixDestroy(&pixt1);
-    pixDestroy(&pixt2);
+    pixDestroy(&pix1);
+    pixDestroy(&pix2);
 
         /* Conversion: 2 bpp cmap --> 32 bpp --> 2 bpp cmap */
-    pixt1 = pixConvertTo8(pixc2, TRUE);
-    pixt2 = pixConvertTo32(pixt1);
-    pixt3 = pixConvertTo32(pixc2);
-    pixEqual(pixt2, pixt3, &same);
+    pix1 = pixConvertTo8(pixc2, TRUE);
+    pix2 = pixConvertTo32(pix1);
+    pix3 = pixConvertTo32(pixc2);
+    regTestComparePix(rp, pix2, pix3);  /* 8 */
+    pixEqual(pix2, pix3, &same);
     if (!same) {
-        pixDisplayWithTitle(pixt2, 100, 100, "32 bpp", DFLAG);
-        pixDisplayWithTitle(pixt3, 500, 100, "32 bpp", DFLAG);
+        pixDisplayWithTitle(pix2, 100, 100, "32 bpp", 1);
+        pixDisplayWithTitle(pix3, 500, 100, "32 bpp", 1);
         error = TRUE;
         sarrayAddString(sa, (char *)"conversion 2 bpp ==> 32 bpp", L_COPY);
     } else
         fprintf(stderr, "OK: conversion 2 bpp <==> 32 bpp\n");
     cmap = pixGetColormap(pixc2);
-    pixt4 = pixOctcubeQuantFromCmap(pixt3, cmap, 2, 4, L_EUCLIDEAN_DISTANCE);
-    pixEqual(pixc2, pixt4, &same);
+    pix4 = pixOctcubeQuantFromCmap(pix3, cmap, 2, 4, L_EUCLIDEAN_DISTANCE);
+    regTestComparePix(rp, pixc2, pix4);  /* 9 */
+    pixEqual(pixc2, pix4, &same);
     if (!same) {
-        pixDisplayWithTitle(pixc2, 100, 100, "4 bpp, cmap", DFLAG);
-        pixDisplayWithTitle(pixt4, 500, 100, "4 bpp, cmap", DFLAG);
+        pixDisplayWithTitle(pixc2, 100, 100, "4 bpp, cmap", 1);
+        pixDisplayWithTitle(pix4, 500, 100, "4 bpp, cmap", 1);
         error = TRUE;
         sarrayAddString(sa, (char *)"conversion 2 bpp <==> 32 bpp", L_COPY);
     } else
         fprintf(stderr, "OK: conversion 2 bpp <==> 32 bpp\n");
-    pixDestroy(&pixt1);
-    pixDestroy(&pixt2);
-    pixDestroy(&pixt3);
-    pixDestroy(&pixt4);
+    pixDestroy(&pix1);
+    pixDestroy(&pix2);
+    pixDestroy(&pix3);
+    pixDestroy(&pix4);
 
         /* Conversion: 4 bpp cmap --> 32 bpp --> 4 bpp cmap */
-    pixt1 = pixConvertTo8(pixc4, TRUE);
-    pixt2 = pixConvertTo32(pixt1);
-    pixt3 = pixConvertTo32(pixc4);
-    pixEqual(pixt2, pixt3, &same);
+    pix1 = pixConvertTo8(pixc4, TRUE);
+    pix2 = pixConvertTo32(pix1);
+    pix3 = pixConvertTo32(pixc4);
+    regTestComparePix(rp, pix2, pix3);  /* 10 */
+    pixEqual(pix2, pix3, &same);
     if (!same) {
-        pixDisplayWithTitle(pixt2, 100, 100, "32 bpp", DFLAG);
-        pixDisplayWithTitle(pixt3, 500, 100, "32 bpp", DFLAG);
+        pixDisplayWithTitle(pix2, 100, 100, "32 bpp", 1);
+        pixDisplayWithTitle(pix3, 500, 100, "32 bpp", 1);
         error = TRUE;
         sarrayAddString(sa, (char *)"conversion 4 bpp ==> 32 bpp", L_COPY);
     } else
         fprintf(stderr, "OK: conversion 4 bpp <==> 32 bpp\n");
     cmap = pixGetColormap(pixc4);
-    pixt4 = pixOctcubeQuantFromCmap(pixt3, cmap, 2, 4, L_EUCLIDEAN_DISTANCE);
-    pixEqual(pixc4, pixt4, &same);
+    pix4 = pixOctcubeQuantFromCmap(pix3, cmap, 2, 4, L_EUCLIDEAN_DISTANCE);
+    regTestComparePix(rp, pixc4, pix4);  /* 11 */
+    pixEqual(pixc4, pix4, &same);
     if (!same) {
-        pixDisplayWithTitle(pixc4, 100, 100, "4 bpp, cmap", DFLAG);
-        pixDisplayWithTitle(pixt4, 500, 100, "4 bpp, cmap", DFLAG);
+        pixDisplayWithTitle(pixc4, 100, 100, "4 bpp, cmap", 1);
+        pixDisplayWithTitle(pix4, 500, 100, "4 bpp, cmap", 1);
         error = TRUE;
         sarrayAddString(sa, (char *)"conversion 4 bpp <==> 32 bpp", L_COPY);
     } else
         fprintf(stderr, "OK: conversion 4 bpp <==> 32 bpp\n");
-    pixDestroy(&pixt1);
-    pixDestroy(&pixt2);
-    pixDestroy(&pixt3);
-    pixDestroy(&pixt4);
+    pixDestroy(&pix1);
+    pixDestroy(&pix2);
+    pixDestroy(&pix3);
+    pixDestroy(&pix4);
 
         /* Conversion: 8 bpp --> 32 bpp --> 8 bpp */
-    pixt1 = pixConvertTo32(pixs8);
-    pixt2 = pixConvertTo8(pixt1, FALSE);
-    pixEqual(pixs8, pixt2, &same);
+    pix1 = pixConvertTo32(pixs8);
+    pix2 = pixConvertTo8(pix1, FALSE);
+    regTestComparePix(rp, pixs8, pix2);  /* 12 */
+    pixEqual(pixs8, pix2, &same);
     if (!same) {
-        pixDisplayWithTitle(pixs8, 100, 100, "8 bpp", DFLAG);
-        pixDisplayWithTitle(pixt2, 500, 100, "8 bpp", DFLAG);
+        pixDisplayWithTitle(pixs8, 100, 100, "8 bpp", 1);
+        pixDisplayWithTitle(pix2, 500, 100, "8 bpp", 1);
         error = TRUE;
         sarrayAddString(sa, (char *)"conversion 8 bpp <==> 32 bpp", L_COPY);
     } else
         fprintf(stderr, "OK: conversion 8 bpp <==> 32 bpp\n");
-    pixDestroy(&pixt1);
-    pixDestroy(&pixt2);
+    pixDestroy(&pix1);
+    pixDestroy(&pix2);
 
         /* Conversion: 8 bpp --> 16 bpp --> 8 bpp */
-    pixt1 = pixConvert8To16(pixs8, 8);
-    pixt2 = pixConvertTo8(pixt1, FALSE);
-    pixEqual(pixs8, pixt2, &same);
+    pix1 = pixConvert8To16(pixs8, 8);
+    pix2 = pixConvertTo8(pix1, FALSE);
+    regTestComparePix(rp, pixs8, pix2);  /* 13 */
+    pixEqual(pixs8, pix2, &same);
     if (!same) {
-        pixDisplayWithTitle(pixs8, 100, 100, "8 bpp", DFLAG);
-        pixDisplayWithTitle(pixt2, 500, 100, "8 bpp", DFLAG);
+        pixDisplayWithTitle(pixs8, 100, 100, "8 bpp", 1);
+        pixDisplayWithTitle(pix2, 500, 100, "8 bpp", 1);
         error = TRUE;
         sarrayAddString(sa, (char *)"conversion 8 bpp <==> 16 bpp", L_COPY);
     } else
         fprintf(stderr, "OK: conversion 8 bpp <==> 16 bpp\n");
-    pixDestroy(&pixt1);
-    pixDestroy(&pixt2);
+    pixDestroy(&pix1);
+    pixDestroy(&pix2);
 
         /* Conversion: 16 bpp --> 8 bpp --> 16 bpp */
-    pixt1 = pixConvert16To8(pixs16, 1);
-    pixt2 = pixConvertTo16(pixt1);
-    pixWrite("/tmp/junkpix.png", pixt2, IFF_PNG);
-    pixEqual(pixs16, pixt2, &same);
+    pix1 = pixConvert16To8(pixs16, 1);
+    pix2 = pixConvertTo16(pix1);
+    pixWrite("/tmp/junkpix.png", pix2, IFF_PNG);
+    regTestComparePix(rp, pixs16, pix2);  /* 14 */
+    pixEqual(pixs16, pix2, &same);
     if (!same) {
-        pixDisplayWithTitle(pixs16, 100, 100, "16 bpp", DFLAG);
-        pixDisplayWithTitle(pixt2, 500, 100, "16 bpp", DFLAG);
+        pixDisplayWithTitle(pixs16, 100, 100, "16 bpp", 1);
+        pixDisplayWithTitle(pix2, 500, 100, "16 bpp", 1);
         error = TRUE;
         sarrayAddString(sa, (char *)"conversion 16 bpp <==> 8 bpp", L_COPY);
     } else
         fprintf(stderr, "OK: conversion 16 bpp <==> 8 bpp\n");
-    pixDestroy(&pixt1);
-    pixDestroy(&pixt2);
+    pixDestroy(&pix1);
+    pixDestroy(&pix2);
 
         /* Conversion: 8 bpp cmap --> 32 bpp --> 8 bpp cmap */
         /* Required to go to level 6 of octcube to get identical result */
-    pixt1 = pixConvertTo32(pixc8);
+    pix1 = pixConvertTo32(pixc8);
     cmap = pixGetColormap(pixc8);
-    pixt2 = pixOctcubeQuantFromCmap(pixt1, cmap, 2, 6, L_EUCLIDEAN_DISTANCE);
-    pixEqual(pixc8, pixt2, &same);
+    pix2 = pixOctcubeQuantFromCmap(pix1, cmap, 2, 6, L_EUCLIDEAN_DISTANCE);
+    regTestComparePix(rp, pixc8, pix2);  /* 15 */
+    pixEqual(pixc8, pix2, &same);
     if (!same) {
-        pixDisplayWithTitle(pixc8, 100, 100, "8 bpp cmap", DFLAG);
-        pixDisplayWithTitle(pixt2, 500, 100, "8 bpp cmap", DFLAG);
+        pixDisplayWithTitle(pixc8, 100, 100, "8 bpp cmap", 1);
+        pixDisplayWithTitle(pix2, 500, 100, "8 bpp cmap", 1);
         error = TRUE;
         sarrayAddString(sa, (char *)"conversion 8 bpp cmap <==> 32 bpp cmap",
                         L_COPY);
     } else
         fprintf(stderr, "OK: conversion 8 bpp <==> 32 bpp\n");
-    pixDestroy(&pixt1);
-    pixDestroy(&pixt2);
+    pixDestroy(&pix1);
+    pixDestroy(&pix2);
 
         /* Summarize results */
     if (error == FALSE)
@@ -324,6 +338,6 @@ static char  mainName[] = "convert_reg";
     pixDestroy(&pixc8);
     pixDestroy(&pixs16);
     pixDestroy(&pixs32);
-    return 0;
+    return regTestCleanup(rp);
 }
 
